# PIVA - Python Interactive Viewer for Arpes

PIVA is a GUI-application for data visualisation from Angle-Resolved 
Photoemission Spectroscopy (ARPES) experiments.

![](https://raw.githubusercontent.com/pudeIko/piva/master/doc/img/piva_showcase.gif)

PIVA is intended to support ARPES experimenters by providing a python tool 
for fast inspection of acquired data.
It has been developed by beamline scientists for that exact purpose and 
contains functionality for preliminary analysis that is often required during 
an ARPES experiement.

Please refer to the [documentation](https://piva.readthedocs.io/en/latest/) 
for more.
